# Task Manager MCP Servers

[![PyPI version](https://badge.fury.io/py/task-manager-mcp.svg)](https://badge.fury.io/py/task-manager-mcp)
[![Python Support](https://img.shields.io/pypi/pyversions/task-manager-mcp.svg)](https://pypi.org/project/task-manager-mcp/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Tests](https://github.com/task-manager-mcp/task-manager-mcp/workflows/Tests/badge.svg)](https://github.com/task-manager-mcp/task-manager-mcp/actions)

Two powerful Model Context Protocol (MCP) servers that provide intelligent task management and assignment capabilities for AI assistants like Claude Desktop.

## 🚀 Features

### Task Management MCP Server
- **Intelligent Task Analysis**: Convert natural language into structured tasks with priorities, time estimates, and risk assessments
- **Smart Scheduling**: Generate optimal task ordering and completion timelines
- **Risk Prediction**: Identify potential risks and provide mitigation strategies
- **Automated Reminders**: Set up deadline and progress check notifications
- **Progress Tracking**: Dynamic progress updates with automatic estimate adjustments
- **Task Review**: Comprehensive retrospective analysis for continuous improvement

### Task Assignment MCP Server  
- **Task Decomposition**: Break complex tasks into manageable subtasks using AI
- **Capability Matching**: Match tasks to resources based on skills and availability
- **Smart Assignment**: Intelligent resource allocation considering workload and expertise
- **Team Collaboration**: Coordinate multi-person tasks with collaboration plans
- **Daily Report Review**: Automated scoring and feedback for team performance
- **Workload Management**: Track and balance team capacity

## 📦 Installation

```bash
pip install task-manager-mcp
```

## 🔧 Quick Start

### 1. Set up Environment Variables

```bash
export OPENAI_API_KEY="your-openai-api-key"
export OPENAI_BASE_URL="https://api.openai.com/v1"  # Optional
```

### 2. Configure Claude Desktop

Add to your Claude Desktop configuration file:

**macOS**: `~/Library/Application Support/Claude/claude_desktop_config.json`
**Windows**: `%APPDATA%\Claude\claude_desktop_config.json`

```json
{
  "mcpServers": {
    "task-management": {
      "command": "python",
      "args": ["-m", "task_management_mcp.server"],
      "env": {
        "OPENAI_API_KEY": "your-openai-api-key"
      }
    },
    "task-assignment": {
      "command": "python", 
      "args": ["-m", "task_assignment_mcp.server"],
      "env": {
        "OPENAI_API_KEY": "your-openai-api-key"
      }
    }
  }
}
```

### 3. Start Using

Restart Claude Desktop and start using the task management capabilities:

```
"I need to build a user authentication system for my web app. Can you help me analyze this task and create a plan?"
```

## 🛠️ Available Tools

### Task Management MCP

| Tool | Description |
|------|-------------|
| `analyze_task_input` | Convert natural language into structured tasks |
| `get_schedule_recommendation` | Generate optimal task scheduling |
| `predict_task_risks` | Identify risks and mitigation strategies |
| `create_reminder` | Set up automated reminders |
| `update_task_progress` | Track and update task progress |
| `get_next_task_recommendation` | Get intelligent next task suggestions |

### Task Assignment MCP

| Tool | Description |
|------|-------------|
| `decompose_complex_task` | Break tasks into manageable subtasks |
| `recommend_task_assignment` | Match tasks to optimal resources |
| `assign_task_to_resource` | Create task assignments |
| `create_collaboration_plan` | Plan multi-person task coordination |
| `review_daily_report` | Score and provide feedback on reports |

## 📚 Resources & Prompts

Both servers provide rich resources for accessing task and project data, plus intelligent prompts for task review and risk analysis.

## 🧪 Development

### Setup Development Environment

```bash
git clone https://github.com/task-manager-mcp/task-manager-mcp.git
cd task-manager-mcp
pip install -e ".[dev]"
```

### Run Tests

```bash
pytest
```

### Code Formatting

```bash
black .
isort .
```

### Type Checking

```bash
mypy .
```

## 📖 Documentation

For detailed documentation, examples, and API reference, visit our [documentation site](https://task-manager-mcp.readthedocs.io/).

## 🤝 Contributing

We welcome contributions! Please see our [Contributing Guide](CONTRIBUTING.md) for details.

## 📄 License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## 🙏 Acknowledgments

- Built on the [Model Context Protocol](https://modelcontextprotocol.io/) by Anthropic
- Inspired by modern project management methodologies
- Powered by OpenAI's GPT models for intelligent analysis

## 📞 Support

- 📧 Email: support@taskmanager-mcp.com
- 🐛 Issues: [GitHub Issues](https://github.com/task-manager-mcp/task-manager-mcp/issues)
- 💬 Discussions: [GitHub Discussions](https://github.com/task-manager-mcp/task-manager-mcp/discussions)

---

**Made with ❤️ for the AI-powered productivity community**
