# AI 任务管理系统

这个系统使用FastAPI后端和React前端，通过AI智能体帮助用户规划和管理项目任务。

## 系统功能

- 通过自然语言对话规划项目任务
- 自动分解复杂任务为子任务
- 识别并管理任务间的依赖关系
- 可视化任务流程图

## 快速开始

### 启动服务

```bash
# 给脚本添加执行权限
chmod +x start_services.sh stop_services.sh run_tests.sh

# 启动服务
./start_services.sh
```

首次启动时，系统会提示您输入API密钥和API基础URL。

### 停止服务

```bash
./stop_services.sh
```

### 测试系统

我们提供了两个测试脚本：

1. 综合测试后端API:
```bash
python3 test_backend_comprehensive.py
```

2. 专门测试RouterAgent:
```bash
python3 test_router_agent.py
```

## 环境变量配置

系统需要以下环境变量：

- `OPENAI_API_KEY`: 用于访问AI服务的API密钥
- `OPENAI_BASE_URL`: AI服务的基础URL，默认为 `https://api.nuwaapi.com`

这些变量可以通过以下方式设置：

1. 在系统环境变量中设置
2. 在 `backend/.env` 文件中设置
3. 通过启动脚本交互式设置

## 日志文件

所有日志文件保存在 `logs` 目录下：

- `logs/backend.log`: 后端服务日志

## 故障排除

如果遇到问题，请检查：

1. API密钥是否正确设置
2. API基础URL是否正确
3. 日志文件中的错误信息

## 开发者说明

### 目录结构

- `backend/`: 后端代码
  - `src/`: 源代码
  - `main.py`: 主入口点
- `logs/`: 日志文件
- `project_documents/`: 项目文档
- `*.sh`: 服务管理脚本
- `*.py`: 测试脚本